==> hook_event_dispatcher-8.x-1.7.tar.gz: hook_event_dispatcher/src/Value/Token.php <==
<?php

namespace Drupal\hook_event_dispatcher\Value;

use Drupal\Component\Render\MarkupInterface;

/**
 * Token ValueObject.
 *
 * Convenience object to handle the integrity and assembly of tokens.
 */
final class Token {

  /**
   * Type.
   *
   * @var string
   */
  private $type;
  /**
   * Token.
   *
   * @var string
   */
  private $token;
  /**
   * Description.
   *
   * @var string
   */
  private $description;
  /**
   * Name.
   *
   * @var string|\Drupal\Component\Render\MarkupInterface
   */
  private $name;

  /**
   * Use create function instead.
   */
  private function __construct() {
  }

  /**
   * Token factory function.
   *
   * @param string $type
   *   The group name, like 'node'.
   * @param string $token
   *   The token, like 'url' or 'id'.
   * @param string|MarkupInterface $name
   *   The print-able name of the type.
   *
   * @return \Drupal\hook_event_dispatcher\Value\Token
   *   Creates a new token.
   *
   * @throws \UnexpectedValueException
   */
  public static function create($type, $token, $name) {
    $instance = new self();
    if (!is_string($type)) {
      throw new \UnexpectedValueException('Type should be a string');
    }
    if (!is_string($token)) {
      throw new \UnexpectedValueException('Token should be a string');
    }
    if (!is_string($name) && !$name instanceof MarkupInterface) {
      throw new \UnexpectedValueException('Name should be a string or an instance of MarkupInterface');
    }
    $instance->type = $type;
    $instance->token = $token;
    $instance->name = $name;
    return $instance;
  }

  /**
   * Set description and return a new instance.
   *
   * @param string $description
   *   The description of the token type.
   *
   * @return self
   *   New instance with the description.
   *
   * @throws \UnexpectedValueException
   */
  public function setDescription($description) {
    if (!is_string($description) && !$description instanceof MarkupInterface) {
      throw new \UnexpectedValueException('Description should be a string or an instance of MarkupInterface');
    }
    $clone = clone $this;
    $clone->description = $description;
    return $clone;
  }

  /**
   * Getter.
   *
   * @return string|MarkupInterface|null
   *   The description.
   */
  public function getDescription() {
    return $this->description;
  }

  /**
   * Getter.
   *
   * @return string
   *   The type like 'node'.
   */
  public function getType() {
    return $this->type;
  }

  /**
   * Getter.
   *
   * @return string|MarkupInterface
   *   The label of the token.
   */
  public function getName() {
    return $this->name;
  }

  /**
   * Getter.
   *
   * @return string
   *   The token name like 'url'.
   */
  public function getToken() {
    return $this->token;
  }

}

==> hook_event_dispatcher-8.x-1.21.tar.gz: hook_event_dispatcher/src/Value/Token.php <==
<?php

namespace Drupal\hook_event_dispatcher\Value;

use Drupal\Component\Render\MarkupInterface;

/**
 * Token ValueObject.
 *
 * Convenience object to handle the integrity and assembly of tokens.
 */
final class Token {

  /**
   * Type.
   *
   * @var string
   */
  private $type;
  /**
   * Token.
   *
   * @var string
   */
  private $token;
  /**
   * Description.
   *
   * @var string
   */
  private $description;
  /**
   * Name.
   *
   * @var string|\Drupal\Component\Render\MarkupInterface
   */
  private $name;

  /**
   * Use create function instead.
   */
  private function __construct() {
  }

  /**
   * Token factory function.
   *
   * @param string $type
   *   The group name, like 'node'.
   * @param string $token
   *   The token, like 'url' or 'id'.
   * @param string|\Drupal\Component\Render\MarkupInterface $name
   *   The print-able name of the type.
   *
   * @return \Drupal\hook_event_dispatcher\Value\Token
   *   Creates a new token.
   *
   * @throws \UnexpectedValueException
   */
  public static function create($type, $token, $name) {
    $instance = new self();
    if (!\is_string($type)) {
      throw new \UnexpectedValueException('Type should be a string');
    }
    if (!\is_string($token)) {
      throw new \UnexpectedValueException('Token should be a string');
    }
    if (!\is_string($name) && !$name instanceof MarkupInterface) {
      throw new \UnexpectedValueException('Name should be a string or an instance of MarkupInterface');
    }
    $instance->type = $type;
    $instance->token = $token;
    $instance->name = $name;
    return $instance;
  }

  /**
   * Set description and return a new instance.
   *
   * @param string $description
   *   The description of the token type.
   *
   * @return self
   *   New instance with the description.
   *
   * @throws \UnexpectedValueException
   */
  public function setDescription($description) {
    if (!\is_string($description) && !$description instanceof MarkupInterface) {
      throw new \UnexpectedValueException('Description should be a string or an instance of MarkupInterface');
    }
    $clone = clone $this;
    $clone->description = $description;
    return $clone;
  }

  /**
   * Getter.
   *
   * @return string|MarkupInterface|null
   *   The description.
   */
  public function getDescription() {
    return $this->description;
  }

  /**
   * Getter.
   *
   * @return string
   *   The type like 'node'.
   */
  public function getType() {
    return $this->type;
  }

  /**
   * Getter.
   *
   * @return string|MarkupInterface
   *   The label of the token.
   */
  public function getName() {
    return $this->name;
  }

  /**
   * Getter.
   *
   * @return string
   *   The token name like 'url'.
   */
  public function getToken() {
    return $this->token;
  }

}
